package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````W!<``#0```!,P0```````#0`(``)
M`"@`&P`:``8````T````-````#0````@`0``(`$```4````$`````P```%0!
M``!4`0``5`$``!,````3````!`````$````!````````````````````+*\`
M`"RO```%`````!````$```#`O0``P,T``,#-``!0`@``E!(```8`````$```
M`@```,B]``#(S0``R,T```@!```(`0``!@````0````$````:`$``&@!``!H
M`0``1````$0````$````!````%#E=&2DH```I*```*2@``#T````]`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DP+T`
M`,#-``#`S0``0`(``$`"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````#`````@`````````$````%`````,```!'
M3E4`6H9O*&P8RZCAHB[0UPI\$&B*JGH1````2P````@````(`````!`0!"5`
M!(`H`0`!H(8`@(`!```+*`0).*`218H$"`@`````2P```$\```!3````5```
M`%H```!;````7````%X```!?`````````&$```!C````9````&4`````````
M`````&[%WQ_JT^\.SMY'+6M_FGPNQ9NV(/_D#KB-\0[59-1\V7%8'.)'Q@&L
M2^/`NN.2?,+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'<-,-%.*>VLWCGC-B
MV^T,.I<+6>CM['^IG)OAIP(*H^#[20````````````````````"3`@``````
M```````2````00,`````````````$@```.H!`````````````!(````1````
M```````````@````6@,`````````````$0```,`#`````````````!(```#@
M`@`````````````1````,@,`````````````$@```!$!`````````````!(`
M``!^`@`````````````2````K@(`````````````$@```+0`````````````
M`!(```"#`0`````````````2````F@(`````````````$@```(0`````````
M`````!(````,`0`````````````2````9`,`````````````$@```.<"````
M`````````!(````!`0`````````````1````6P(`````````````$@```&<!
M`````````````!(```#C```````````````1````[@(`````````````$@``
M`#4!`````````````!(```#"```````````````2````%0,`````````````
M(@```+$!`````````````!(````S`@`````````````2````X@$`````````
M````$@```'<"`````````````!(```">`0`````````````2````:`(`````
M````````$@```*H!`````````````!(```!#`0`````````````2````]P(`
M````````````$@```"T``````````````"````!%`@`````````````2````
MO`$`````````````$0````0#`````````````!(```!D```````````````2
M````C`(`````````````$@```$@#`````````````!(```#;`0``````````
M```2````DP``````````````$@```)\``````````````!(```!<`0``````
M```````2````8@(`````````````$@```"(!`````````````!(````#`@``
M```````````2````<`(`````````````$@```%8``````````````!(````6
M`0`````````````2````M0(`````````````$@```),!`````````````!(`
M``#P```````````````2````.@,`````````````$@```(4"````````````
M`!(```!;`P`````````````A````=0$`````````````$@```',`````````
M`````!(```#4```````````````2````4P$`````````````$@````L#````
M`````````!(```"@`@`````````````2````/```````````````(````$H"
M`````````````!(```!<`P`````````````1````U@(`````````````$@``
M`.\!`````````````!(```##`@`````````````2````%`(`````````````
M$@```%("`````````````!(```#.`@`````````````2````)`,`````````
M````$@```,D#```08```;P```!(`#@"7`P``5&$````````2``\`[@,``,!/
M``"Q#```$@`.`%4#``"@%0``/`(``!(`#@"=`P```$D```4````2``X`5`0`
M`!!)```E`@``$@`.`$X$``"<$0```````!(`"P"!!```@%P``(8#```2``X`
M?`,``!#0````````$``8`-4#``!`2P``*@```!(`#@`D`@``;&$```0````1
M`!``B`,``%3@````````$``8`$P$``"@1P``.P```!(`#@!A!```\$X``,<`
M```2``X`<P0``#!.``!V````$@`.`/L#````T````````!``%P#B`P``<$L`
M`.<````2``X`=0,``!#0````````$``7`"X$```,T```!````!$`%P"-`P``
M,&$```(````2``X`'@0``-!@``!=````$@`.``$$``#<%P```````!(`#@#]
M`P```-`````````@`!<`.`0``&AA```$````$0`0`*X#``"P3@``-````!(`
M#@`(!```0$@``+D````2``X`/P0``&!,``#$`0``$@`.``!L:6)P97)L+G-O
M+C4N,C8`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R
M=%]?`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!0
M97)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T
M`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI
M9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD
M=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R
M;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R
M;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C
M=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E
M<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI
M8G!T:')E860N<V\N,`!O<&5N-C0`;'-E96LV-`!R96%D`'!T:')E861?9V5T
M<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L:6)C+G-O+C8`7TE/
M7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP`&-L
M;W-E9&ER`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R
M9'5P`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`
M;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T
M870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`%]?;65M8W!Y7V-H:P!S=')C
M:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`;65M
M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O
M;@!?7W-T86-K7V-H:U]F86EL`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`%]?
M;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F
M<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER
M;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T`'!A<E]C=7)R96YT7V5X
M96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]F<%]H=P!P87)?
M:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A
M=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?
M,BXR`$=,24)#7S(N,`!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R
M+C$N,P!'3$E"0U\R+C0``````@`"``,````"``(``@`"``(``@`"```````"
M```````$``(````"```````"```````%````!@`'``(````"``(````(````
M`@````(````"``(`!P`````````"`````P`"```````(```````"``(``@``
M``````````D`"`````(``@`)``,`"0`#``(``@`(``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!`````0`"
M`,L!```0````,````!)I:0T```<`EP0``!`````0:6D-```#`*$$````````
M`0`&`!H"```0`````````!)I:0T```D`EP0``!````!T&6D)```(`*L$```0
M````<AEI"0``!@"W!```$````',?:0D```4`PP0``!`````4:6D-```$`,\$
M```0````$&EI#0```@"A!````````,#-```(````Q,T```@```#PSP``"```
M``30```(````#-````@```#,SP``!@0``-#/```&!P``U,\```8-``#8SP``
M!A,``-S/```&%@``X,\```8:``#DSP``!B0``.C/```&)@``[,\```8P``#T
MSP``!CP``/C/```&00``_,\```9#``#<S@``!P$``.#.```'`@``Y,X```<#
M``#HS@``!P8``.S.```'"```\,X```<)``#TS@``!PH``/C.```'"P``_,X`
M``<,````SP``!PX```3/```'#P``",\```<0```,SP``!Q$``!#/```'$@``
M%,\```<4```8SP``!Q4``!S/```'%P``(,\```<8```DSP``!QD``"C/```'
M&P``+,\```<<```PSP``!QT``#3/```''@``.,\```<?```\SP``!R```$#/
M```'(0``1,\```<B``!(SP``!R,``$S/```')0``4,\```<G``!4SP``!R@`
M`%C/```'*0``7,\```<J``!@SP``!RL``&3/```'+```:,\```<M``!LSP``
M!RX``'#/```'+P``=,\```<Q``!XSP``!S(``'S/```',P``@,\```<T``"$
MSP``!S4``(C/```'-@``C,\```<W``"0SP``!S@``)3/```'.0``F,\```<[
M``"<SP``!ST``*#/```'/@``I,\```<_``"HSP``!T```*S/```'0@``L,\`
M``=$``"TSP``!T4``+C/```'1@``O,\```='``#`SP``!T@``,3/```'20``
MR,\```=*``!3@^P(Z'L&``"!PRN]``"+@Q0!``"%P'0%Z-X#``"#Q`A;PP#_
MLP0```#_HP@`````````_Z,,````:`````#IX/____^C$````&@(````Z=#_
M____HQ0```!H$````.G`_____Z,8````:!@```#IL/____^C'````&@@````
MZ:#_____HR````!H*````.F0_____Z,D````:#````#I@/____^C*````&@X
M````Z7#_____HRP```!H0````.E@_____Z,P````:$@```#I4/____^C-```
M`&A0````Z4#_____HS@```!H6````.DP_____Z,\````:&````#I(/____^C
M0````&AH````Z1#_____HT0```!H<````.D`_____Z-(````:'@```#I\/[_
M__^C3````&B`````Z>#^____HU````!HB````.G0_O___Z-4````:)````#I
MP/[___^C6````&B8````Z;#^____HUP```!HH````.F@_O___Z-@````:*@`
M``#ID/[___^C9````&BP````Z8#^____HV@```!HN````.EP_O___Z-L````
M:,````#I8/[___^C<````&C(````Z5#^____HW0```!HT````.E`_O___Z-X
M````:-@```#I,/[___^C?````&C@````Z2#^____HX````!HZ````.D0_O__
M_Z.$````:/````#I`/[___^CB````&CX````Z?#]____HXP```!H``$``.G@
M_?___Z.0````:`@!``#IT/W___^CE````&@0`0``Z<#]____HY@```!H&`$`
M`.FP_?___Z.<````:"`!``#IH/W___^CH````&@H`0``Z9#]____HZ0```!H
M,`$``.F`_?___Z.H````:#@!``#I</W___^CK````&A``0``Z6#]____H[``
M``!H2`$``.E0_?___Z.T````:%`!``#I0/W___^CN````&A8`0``Z3#]____
MH[P```!H8`$``.D@_?___Z/`````:&@!``#I$/W___^CQ````&AP`0``Z0#]
M____H\@```!H>`$``.GP_/___Z/,````:(`!``#IX/S___^CT````&B(`0``
MZ=#\____H]0```!HD`$``.G`_/___Z/8````:)@!``#IL/S___^CW````&B@
M`0``Z:#\____H^````!HJ`$``.F0_/___Z/D````:+`!``#I@/S___^CZ```
M`&BX`0``Z7#\____H^P```!HP`$``.E@_/___Z/P````:,@!``#I4/S___^C
M]````&C0`0``Z4#\____H_@```!HV`$``.DP_/___Z,0`0``9I#_HQ0!``!F
MD(U,)`2#Y/#_<?Q5B>575E-1B<_H:`(``('#&+D``(/L+(M!!(E%U(M!"(E%
MT&6A%````(E%Y#'`C4704(U%U%!1Z,K]__^+@QP!``"#Q`Q04/^S)`$``.B4
M2@``BX,,`0``@\00@#@`#X0B`0``B[,(`0``@^P,_S;H$O___X"(_@(```):
M_S;H`____X"(_@(```&+!X/$$(/`!3W___\_#X=5`0``@^P,P>`"4.CM_/__
MBW74BP^#Q!")@W01``#'@W@1```$````BQ:#^0&)$(V3<)3__XE0!(N3/`$`
M`(E0"(V3<Y3__XE0#'X7N@$```"-="8`BSR6B7R0#(/"`3G1=?*#[`S'1(@,
M`````(/!`VH`4(V#$'G__U%0_[.`$0``Z+;]__^#Q""%P(G&#X2M````@^P,
M_[.`$0``C7W@Z-C[__^-@T"3__^)^N@+*@``@\00A<!T;8/L#/^S@!$``.AV
M^___Z$']__^#Q!")\(M-Y&4S#10````/A:D```"-9?!96UY?78UA_,/HR_O_
M_X7`B8.`$0``#X2/````@^P,4.@D^___B[,(`0``6?\VZ-;]__^#Q!#&@'$%
M````Z:O^__^+@WP1``"%P'0]@^P,4.B42```@\00Z7C___^#[`S_LX`1``#H
M3OW__X/$$(G&Z3O___]04(V#\I+___^S&`$``%#H4/S__XV#]9+__XGZZ$,I
M``"%P(F#?!$```^$,?___^NFZ&Y)``"#[`QJ`>BT^___,>U>B>&#Y/!05%+H
M(@```('#Y+8``(V#8)+__U"-@P"2__]045;_LR`!``#HP_O___2+'"3#9I!F
MD&:09I!FD&:09I"+'"3#9I!FD&:09I!FD&:0Z.0```"!PINV``"-BD`!``"-
M@D`!```YR'0=BX+\````A<!T$U6)Y8/L%%'_T(/$$,G#D(UT)@#SPXVV````
M`.BD````@<);M@``58V*0`$``(V"0`$``"G(B>53P?@"B<.#[`3!ZQ\!V-'X
M=!2+DB@!``"%TG0*@^P(4%'_TH/$$(M=_,G#B?:-O"<`````58GE4^A7____
M@<,'M@``@^P$@+M0`0```'4GBX,0`0``A<!T$8/L#/^S-`$``.B=_/__@\00
MZ#7____&@U`!```!BUW\R<.)]HV\)P````!5B>5=Z5?___^+%"3#9I"055>-
M:#A64X'L#`,``(U,)'B)1"14B70D$&6+'10```")G"3\`@``,=N)3"0(B7PD
M%(VT)@````"+5)T`BT2=!,=$V00`````QT39#`````#'1"0$``````_*B00D
MB139B<+!Z!C!Z@B!X@#_```)T(L4)(G'BP0DP>(8P>`("=<E``#_``GXB439
M"(/#`H/[$'6EBT0D"(V4)'@"``")%"2)Q9"-="8`BU5HBT5L@\4(,U4X,T4\
M,U4(,T4,,U7X,T7\QT5\`````(G'B=")T0^L^!\!T0G!B4UX.RPD=<B+7"14
MBU,,BTL<BS.+>P2+0PB)5"0<BU,4B4PD#(M+)(E$)!B+0Q")5"0$BU,8B4PD
M7(E\)!2)!"2)5"0(BU,@BUPD!(E4)%B)\L'F!8G1B?6+="18#ZSY&XM\)`B)
M5"00"<T#="1XB>B)\8MT)`R!P9EY@EH!R(L,)#'>(W0D'#'/BTPD&(ET)"`A
MSXG^BWPD"#'^`?")1"0@BWPD&(ML)!R+!"2+5"0$QT0D)`````")^8G^QT0D
M/``````/K.X"P>$>B<>+1"00B<V+3"0(QT0D+``````)]0.,)(````")UHEL
M)#");"0XQT0D1`````"!P9EY@EHC="04,>\AQXET)"B)_HL\)#'^BWPD)`'Q
MBW0D((G]B?")]\'@!8E$)"B+="0H#ZSO&XML)!0)_HM\)!")\(LT)`'(B40D
M*(GYB?@/K.@"P>$>BWPD!(G-BTPD,`G%`[0DB````!.\)(P```");"1`B?"+
M="0@!9EY@EJ)^HM\)#B#T@`QZ3';(<['1"1,`````,=$)#P`````,?>)_HG?
MBUPD.`'&BT0D*!'7BU0D+(ET)#")?"0TBWPD)(G&QT0D-``````/K-`;P>8%
MBU0D+(G!"?&+="0@B<@#1"0PB?$/K/X"P>$>B40D,(M\)#`)\0.<))````")
M3"1@B4PD2(G8!9EY@EHQS2-L)"@S;"1`B>F+;"0T`<&)^,'@!8E$)""+="0@
M#ZSO&PG^B?`!R#'_B<:+1"0HB<'!X1X/K-`"B<V+5"1`BTPD8`G%`Y0DF```
M`(EL)#B);"1`B=`%F7F"6C'I(TPD,(ML)$B+5"0TQT0D)`````#'1"0T````
M`,=$)$0`````,<V)Z0'!B?#!X`6)1"0@B?"+;"0@#ZSX&XE$)"@+;"0HB>B+
M;"1``<B)1"0@BT0D,(G!#ZS0`L'A'HM4)$P)P8M$)$@#A"2@````$Y0DI```
M`(E,)#")3"1(!9EY@EJ#T@`QS3';(?4S;"0XB>D!P8M$)"`1TXM4)"2)3"0H
MB5PD+,=$)"P`````B<'!X06)3"1`B=&+;"1`B<(/K,H;B?$)U8GH`T0D*,'A
M'@^L_@*)S0GUB40D*(EL)$"+7"0X`YPDJ````(MT)#P3M"2L````BTPD2(G8
MB?*+="0@!9EY@EJ#T@`QZ3';B=\ASC-T)#`!QHM$)"@1UXM4)"R)="0XB7PD
M/,=$)#P`````B<8/K-`;P>8%BU0D),=$)"0`````B<$)\8G(`T0D.#'_B<:+
M1"0@B<$/K-`"P>$>BU0D+`G!BT0D,`.$)+````")3"0XB4PD2`69>8):,<TC
M;"0H,VPD0(GI`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D,`ML)#")Z`'(B40D
M((M$)"B)P<'A'@^LT`*)S0G%B6PD,(M4)$`#E"2X````BTPD1!.,)+P```#'
M1"0T`````,=$)$0`````B=`%F7F"6HG*BTPD2(/2`(E$)"@QVXE4)"R+5"0X
M,>DA\3'*B=`#1"0HB=H35"0LB40D*(M$)"")5"0LBU0D),=$)"P`````B<'!
MX06)3"1`B=&)P@^LRAN+3"1`B50D2`M,)$B)R`-$)"B)\0^L_@+!X1X)\8E$
M)"B+1"0X`X0DP````(E,)$")3"1(!9EY@EHQS2-L)"`S;"0PBWPD*(M4)"3'
M1"0\`````,=$)"0`````QT0D-`````")Z8ML)"P!P8GXP>`%B40D.(MT)#@/
MK.\;"?Z)\`'(,?^)QHM$)"")P<'A'@^LT`*)S8M4)#"+3"1("<4#E"3(````
MB6PD.(EL)$B)T(M4)"P%F7F"6C'I(TPD*(ML)$`QS8GI`<&)\,'@!8E$)"")
M\(ML)"`/K/@;B40D,`ML)#")Z`'(B40D((M$)"B)P0^LT`+!X1Z+5"1$"<&+
M1"1``X0DT````!.4)-0```")3"0PB4PD8(ML)$C'1"1$``````69>8):@](`
M,<TQVR'U,VPD.(GI`<&+1"0@$=.+5"0DB4PD*(E<)"R+7"0XB<''1"0L````
M`,'A!8E,)$")T8ML)$")P@^LRAN)\0G5B>@#1"0HP>$>#ZS^`HG-BTPD8`GU
M`YPDV````(MT)#P3M"3<````B40D*(EL)$")V(GRBW0D(`69>8):@](`,>DQ
MVXG?(<XS="0P`<:+1"0H$=>+5"0LB70D.(E\)#S'1"0\`````(G&#ZS0&\'F
M!8M4)"2)P0GQB<@#1"0X,?^)QHM$)"")P0^LT`+!X1X)P8E,)#B+1"0P`X0D
MX````(E,)$B+5"0LQT0D)`````#'1"0T``````69>8):,<TC;"0H,VPD0(GI
M`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D,`ML)#")Z`'(B40D((M$)"B)P<'A
M'@^LT`*)S8M4)$"+3"1$"<4#E"3H````$XPD[````(EL)#")T`69>8):B<J+
M3"1(@](`B40D*#';B50D+(M4)#@QZ2'Q,<J)T`-$)"B)VA-4)"R)1"0HBT0D
M((E4)"R+5"0DB<'!X06)3"1`B=&)P@^LRAN+3"1`BUPD.(E4)$@+3"1(QT0D
M+`````"+5"0DQT0D1`````#'1"0\`````(G(B?$#1"0H#ZS^`L'A'@GQ`YPD
M\````(E$)"B+?"0HB4PD2(E,)$")V`69>8):,<TC;"0@,VPD,(GIBVPD+`'!
MB?C!X`6)1"0XBW0D.`^L[QL)_HGP`<@Q_XG&BT0D((G!P>$>#ZS0`HG-BU0D
M,(M,)$@)Q0.4)/@```");"0XB6PD2(G0!9EY@EHQZ2-,)"B+;"1`,<V)Z0'!
MB?#!X`6)1"0@B?`/K/@;B40D,(ML)"`+;"0PBU0D+,=$)"0`````QT0D-```
M``")Z(ML)$@!R(E$)""+1"0HB<$/K-`"P>$>BU0D1,=$)$0`````"<&+1"1`
M`X0D``$``!.4)`0!``")3"1@B4PD,`69>8):@](`,<TQVR'U,VPD.(GI`<&+
M1"0@$=.+5"0DB4PD*(E<)"R+7"0XB<''1"0L`````,'A!8E,)$")T8ML)$")
MP@^LRAN+3"1@"=6)\HGH`T0D*,'B'@^L_@*)U0GU`YPD"`$``(E$)"B);"1`
MB6PD8(MT)""+5"0LB=@%F7F"6C'I(<XS="0PB?$!P8M$)"B)Q@^LT!O!Y@6+
M5"0DQT0D)`````")1"0XBVPD.(M$)"`)]0'I,?^+;"1@B<Z)3"1(B<'!X1X/
MK-`"B<N+5"0P"<,#E"00`0``B5PD,(G0BU0D1`69>8):,=TC;"0H,VPD0(M<
M)"R)Z0'!B?#!X`6)1"0@B?"+;"0@#ZSX&XE$)#@+;"0X`>F)3"1@B4PD((M,
M)"B)R,'@'@^LV0*)Q8M$)$`)S0.$)!@!``"+3"0P$Y0D'`$``(EL)#@%H>O9
M;H/2`#'IBVPD2#';QT0D-``````QS8GI`<&+1"0@$=.+5"0DB4PD*(E<)"R)
M\\=$)"P`````B<'!X06)3"1`B=&+;"1`B<(/K,H;BTPD*`G5B?(!Z<'B'HG5
MBY0D(`$``(E,)$@/K/L"B4PD*(M,)#`)W8'"H>O9;HM<)"R)T(EL)$"+5"0D
M`<@S;"0XB>F+;"1@,<V+3"0HB>X!QHG(P>`%B40D,(M$)""+;"0P#ZS9&XGS
M"<V)P0'KP>$>#ZS0`HG-BY0D*`$``(E<)#`)Q8M$)#B)7"1@B>^+;"1`@<*A
MZ]ENB7PD.`'0,?V+?"0PB>Z+;"1(,?6)Z8ML)#0!P8GXP>`%B40D((MT)"`/
MK.\;BT0D*(M4)"P)_L=$)"0`````QT0D+``````!\8E,)$B)3"0@B<'!X1X/
MK-`"B<V+C"0P`0``BU0D)`G%BT0D0(GNBVPD.('!H>O9;HET)$`!R#'UB>Z+
M;"1@,?6)Z0'!BT0D((G&#ZS0&\'F!8M4)#2)1"0HBVPD*(M$)#`)]0'I,?^)
MSHE,)&")P<'A'@^LT`*)RXN4)#@!```)PXM$)#B)W8E<)#B+7"1`@<*AZ]EN
M`="+5"0D,>N+;"1(,=V)Z0'!B?#!X`6)1"0HB?"+;"0H#ZSX&XE$)#`+;"0P
MBT0D(`'IB4PD2(E,)"B)P<'A'@^LT`*)S0G%B6PD,(N4)$`!``"+C"1$`0``
MBT0D0(ML)#B!PJ'KV6Z#T0")RXG1,=(!R!':,VPD,(E$)"")5"0DBU0D8#';
MB=F+1"0HBYPD2`$``#'J`U0D(!-,)"2)5"0@BU0D+(E,)"2)P<=$)"0`````
MP>$%B4PD0(G1BVPD0(G"BT0D.`^LRAN+3"0@"=6+5"0D`>F)3"0@B4PD8(GQ
MP>$>#ZS^`HG-"?6!PZ'KV6Z)[XML)#`!V(E\)#@Q_8GNBVPD2#'UB>D!P8M$
M)"")RXG&#ZS0&\'F!8E$)$"+;"1`BT0D*`GU`>N)P3'_B5PD2(M4)"S!X1Z)
MWL=$)"P`````#ZS0`HN4)%`!```)P8M$)#")S8M,)#B!PJ'KV6Z);"1``="+
M5"0D,>F+;"1@,<V)Z0'!B=C!X`6)1"0HB=B+;"0H#ZSX&XE$)#`+;"0PBT0D
M(`'IB4PD*(E,)&")P<'A'@^LT`*+E"18`0``B<V+C"1<`0``"<6+1"0XB6PD
M,(ML)$"!PJ'KV6Z#T0")RXG1,=(!R!':,VPD,(E$)"")5"0DBU0D2#';B=F+
M1"0H,>H#5"0@$TPD)(E4)""+5"0LB4PD)(G!P>$%B4PD.(G1BVPD.(G"BYPD
M8`$``(M$)$`/K,H;BTPD(,=$)"0`````"=6+5"0D`>F)3"1(B4PD((GQP>$>
M#ZS^`HG-"?6!PZ'KV6Z)[XML)#`!V(E\)#@Q_8GNBVPD8#'UB>D!P8M$)"")
MQ@^LT!O!Y@6+5"0LQT0D+`````")1"1`BVPD0(M$)"@)]0'I,?^)SHE,)&")
MP<'A'@^LT`*)RXN4)&@!```)PXM$)#")W8E<)$"+7"0X@<*AZ]EN`="+5"0D
M,>N+;"1(,=V)Z0'!B?#!X`6)1"0HB?"+;"0H#ZSX&XE$)#`+;"0PBT0D(`'I
MB4PD2(E,)"B)P<'A'@^LT`*)S0G%B6PD,(N4)'`!``"+C"1T`0``BT0D.(ML
M)$"!PJ'KV6Z#T0")RXG1,=(!R!':,VPD,(E$)"")5"0DBU0D8#';B=F+1"0H
MBYPD>`$``#'J`U0D(!-,)"2)5"0@BU0D+(E,)"2)P<=$)"0`````P>$%B4PD
M.(G1BVPD.(G"BT0D0`^LRAN+3"0@"=6+5"0D`>F)3"0@B4PD8(GQP>$>#ZS^
M`HG-"?6!PZ'KV6Z)[XML)#`!V(E\)#@Q_8GNBVPD2#'UB>D!P8M$)"")RXG&
M#ZS0&\'F!8E$)$"+;"1`BT0D*`GU`>N)P3'_B5PD2(M4)"S!X1Z)WL=$)"P`
M````#ZS0`HN4)(`!```)P8M$)#")S8M,)#B!PJ'KV6Z);"1``="+5"0D,>F+
M;"1@,<V)Z0'!B=C!X`6)1"0HB=B+;"0H#ZSX&XE$)#`+;"0PBT0D(`'IB4PD
M*(E,)&")P<'A'@^LT`*+E"2(`0``B<V+C"2,`0``"<6+1"0XB6PD,(ML)$"!
MPJ'KV6Z#T0")RXG1,=(!R!':,VPD,(E$)"")5"0DBU0D2#';B=F+1"0H,>H#
M5"0@$TPD)(E4)""+5"0LB4PD)(G!P>$%B4PD.(G1BVPD.(G"BYPDD`$``(M$
M)$`/K,H;BTPD(,=$)"0`````"=6+5"0D`>F)3"0@B4PD.(GQP>$>#ZS^`HG-
M"?6!PZ'KV6Z)[XML)#`!V(E\)$`Q_8GNBVPD8#'UB>D!P8M$)"")Q@^LT!O!
MY@6+5"0LQT0D+`````")1"1(BVPD2(M$)"@)]0'I,?^)SHE,)&")P<'A'@^L
MT`*+E"28`0``B<N+C"2<`0``"<.+1"0PB=V!PJ'KV6Z);"1(@]$`B<N)T3'2
M`<@1VHM<)$`QZXML)#@QW3';B>D!P8GP$=/!X`4QTHE$)"B)\(ML)"@/K/@;
MB40D,`ML)#"+1"0@`>D1TXG*B<&)7"1LB50D:,'A'HE4)"B+5"0DB<V+C"2D
M`0``QT0D-``````/K-`"BY0DH`$```G%BT0D0(EL)#B+;"1(@<*AZ]EN@]$`
MB<N)T3'2`<@1VC-L)#B)1"0@B50D)(M4)&`QVXG9BT0D*(N<)*@!```QZ@-4
M)"`33"0DB50D((M4)"R)3"0DB<'!X06)3"0PB=&+;"0PB<*+1"1(#ZS*&XM,
M)"`)U0'IB4PD,(E,)$")\<'A'@^L_@*)S8M\)#`)]8'#H>O9;@'8BUPD.(EL
M)&`QZXML)&@QW8GIBVPD-`'!B?C!X`6)1"0@BW0D(`^L[QL)_HGP`<B)1"0@
MBT0D*(M4)"R+="1@BWPD0,=$)"0`````B<''1"0L`````,=$)$P`````#ZS0
M`L'A'HN4)+`!``")\XG-QT0D/``````)Q8M$)#B!PJ'KV6Z);"1(`=`QZXM4
M)"0QWXN<)+P!``")^0'!BT0D(,'@!8E$)"B+1"0@BWPD*`^LT!N+5"0TB40D
M.`M\)#B)^`'(B40D*(M$)#")P0^LT`+!X1X)P8GPB<^)3"0XBXPDN`$``('!
MW+P;CX/3`#'2`<B+3"1($=H)_2-L)"`QVR'YB<X)[HGQ`<&+1"0H$=.+5"0L
MB4PD,(E<)#2)P<'A!8E,)$")T8ML)$")P@^LRAL)U8GH`T0D,(M4)"0QVXMT
M)$C'1"0T`````,=$)$0`````B40D,(M$)"")P<'A'@^LT`*)S8GYB?H)Q8M$
M)"@)Z2'JB6PD0"'(B<<)UP.T),`!``")^8M\)$P3O"3$`0``QT0D3`````")
M\(G.!=R\&X^)^HG?@](``<:+1"0P$=>+5"0TB70D((E\)"2)Q@^LT!O!Y@6+
M5"0LB<$)\8G(`T0D(#'_B<:+1"0HB<$/K-`"P>$>"<&+1"0XB<H)S8E,)$@C
M;"0PB4PD8(M,)$`AT0G-`X0DR`$``(GI!=R\&X\!P8GPP>`%B40D((GP#ZSX
M&XE$)"B+;"0@"VPD*(M4)#3'1"0D`````,=$)#0`````QT0D/`````")Z`'(
M,=N)1"0@BT0D,(G!P>$>#ZS0`HM4)&")S0G%B6PD,`GJB="+5"1((?`AZ@G0
MBU0D1(G!BT0D0`.$)-`!```3E"34`0``!=R\&X^#T@`!P8M$)"`1TXM4)"2)
M3"0HB5PD+,=$)"P`````B<'!X06)3"0XB=&)P@^LRAN+3"0XB50D0`M,)$")
MR`-$)"B)\<'A'HE$)"B)\`^L^`*+?"0P"<$)S2-L)"")3"0X(<^)3"1@BW0D
M2(M4)"3'1"1$``````G]`[0DV`$``(M\)"B)Z8ML)"R)\`7<O!N/`<&)^,'@
M!8E$)$"+="1`#ZSO&PG^B?`!R#'_,=N)QHM$)"")P<'A'@^LT`*)S8M4)&`)
MQ8M$)"B);"1`">HAT(M4)#@AZ@G0BU0D-,=$)#0`````B<&+1"0P`X0DX`$`
M`!.4).0!```%W+P;CX/2``'!B?`1T\'@!8E,)"")P8GPBU0D+`^L^!N)7"0D
MQT0D)`````")1"0P"TPD,(G(`T0D(#';B40D((M$)"B)P0^LT`+!X1X)P8G*
M"<V)3"0PB4PD2(M,)$`A]8M$)#@AT8M4)#S'1"0\``````G-`X0DZ`$``!.4
M).P!``")Z07<O!N/@](``<&+1"0@$=.+5"0DB4PD*(E<)"S'1"0L`````(G!
MP>$%B4PD.(G1BVPD.(G"#ZS*&XGQ"=6+5"1(B>@#1"0HP>$>B<TQVXE$)"B)
M\(MT)$`/K/@""<6+1"0@">J);"0X(="+5"0PB<<AZ@G7`[0D\`$``(GYBWPD
M1!.\)/0!``")\(G.!=R\&X^)^HG?@](``<:+1"0H$=>+5"0LB70D0(E\)$2)
MQ@^LT!O!Y@6)P0GQB<@#1"1`,?^)QHM$)""+5"0DQT0D)`````#'1"1$````
M`,=$)#0`````B<$/K-`"P>$>"<&+1"0PB<J)3"1`B4PD2`G-BTPD."-L)"@A
MT8M4)"P)S0.$)/@!``")Z07<O!N/`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D
M,`ML)#")Z`'(,=N)1"0@BT0D*(G!P>$>#ZS0`HM4)$B)S0G%B6PD,`GJB="+
M5"1`(?`AZ@G0BU0D/(G!BT0D.`.$)``"```3E"0$`@``!=R\&X^#T@`!P8M$
M)"`1TXM4)"2)3"0HB5PD+(G!P>$%B4PD.(G1B<(/K,H;B50D2(M,)#@+3"1(
MQT0D+`````"+5"0DQT0D/`````#'1"1$`````(G(`T0D*(GQP>$>B40D*(GP
MBW0D0`^L^`*+?"0P"<$)S2-L)"")3"0X(<^)3"1("?T#M"0(`@``BWPD*(GI
MBVPD+(GP!=R\&X\!P8GXP>`%B40D0(MT)$`/K.\;"?Z)\`'(,?\QVXG&BT0D
M((G!P>$>#ZS0`HG-BU0D2`G%BT0D*(EL)$`)ZB'0BU0D."'J"="+5"0TB<&+
M1"0P`X0D$`(``!.4)!0"```%W+P;CX/2``'!B?`1T\'@!8E,)"")P8GPB5PD
M)`^L^!N)1"0P"TPD,(M4)"S'1"0D`````,=$)#0`````B<@#1"0@,=N)1"0@
MBT0D*(G!#ZS0`L'A'@G!BT0D.(G*B4PD,(E,)$@)S8M,)$`A]2'1BU0D/,=$
M)#P`````"<T#A"08`@``$Y0D'`(``(GI!=R\&X^#T@`!P8M$)"`1TXM4)"2)
M3"0HB5PD+,=$)"P`````B<'!X06)3"0XB=&+;"0XB<(/K,H;B?$)U8M4)$B)
MZ`-$)"C!X1Z)S3';B40D*(GPBW0D0`^L^`()Q8M$)"`)ZHEL)#@AT(M4)#")
MQR'J"=>)^8M\)$0#M"0@`@``$[PD)`(``,=$)#0`````B?")S@7<O!N/B?J)
MWX/2``'&BT0D*!'7BU0D+(ET)$")?"1$QT0D1`````")Q@^LT!O!Y@6+5"0D
MQT0D)`````")P0GQB<@#1"1`,?^)QHM$)"")P0^LT`+!X1X)P8M$)#")RHE,
M)$")3"1("<V+3"0X(VPD*"'1BU0D+`G-`X0D*`(``(GI!=R\&X\!P8GPP>`%
MB40D((GPBVPD(`^L^!N)1"0P"VPD,(GH`<@QVXE$)""+1"0HB<'!X1X/K-`"
MBU0D2(G-"<6);"0P">J)T(M4)$`A\"'J"=")P8M$)#@#A"0P`@``BU0D/!.4
M)#0"``#'1"0\``````7<O!N/@](``<&+1"0@$=.+5"0DB4PD*(E<)"S'1"0L
M`````(G!P>$%B4PD.(G1B<(/K,H;BTPD.(E4)$@+3"1(BU0D)(G(`T0D*(GQ
MP>$>B40D*(GPBW0D0`^L^`*+?"0P"<$)S2-L)"")3"0X(<^)3"1("?T#M"0X
M`@``BWPD*(GIBVPD+(GP!=R\&X\!P8GXP>`%B40D0(MT)$`/K.\;"?Z)\`'(
M,?\QVXG&BT0D((G!P>$>#ZS0`HG-"<6);"1`QT0D1`````"+5"1(BT0D*`GJ
M(="+5"0X(>H)T(M4)#2)P8M$)#`#A"1``@``$Y0D1`(```7<O!N/@](``<&)
M\!'3P>`%B4PD((G!B?"+5"0L#ZSX&XE<)"3'1"0D`````(E$)#`+3"0PQT0D
M+`````")R`-$)"`QVXE$)""+1"0HB<$/K-`"P>$>"<&+1"0XB<H)S8E,)"B)
M3"1@BTPD0"'U(=&+5"0\"<T#A"1(`@``$Y0D3`(``(GI!=R\&X^#T@`!P8M$
M)"`1TXM4)"2)3"0PB5PD-(G!P>$%B4PD.(G1BVPD.(G"B?#'1"0T``````^L
MRAN+3"0PQT0D/``````)U8M4)&`!Z8E,)$B)3"0PB?$/K/@"P>$>BW0D0(G-
M"<6+1"0@">J);"1HB6PD."'0BU0D*(G'(>H)UP.T)%`"``"+5"0TB?F)\`7<
MO!N/`<&+1"0PB<N)Q@^LT!N+5"0DP>8%B40D0(ML)$"+1"0@"?4!ZXG!,?\/
MK-`"P>$>BU0D+(ML)&@)P8M$)"@#A"18`@``$Y0D7`(``(E<)&")WHE,)$`%
MUL%BRH/2`#'-B40D((E4)"2+5"1(B=@QZHG1`TPD(,'@!8E$)"")V(ML)"`/
MK/@;BU0D-(M<)$")1"0H"VPD*(M$)##'1"0D``````'IB4PD((E,)$B)P<'A
M'@^LT`*)S8M4)#P)Q8M$)#@#A"1@`@``$Y0D9`(``(EL)#@%UL%BRH/2`#'K
MBVPD8#'=,=N)Z0'!BT0D(!'3BU0D)(E,)"B)7"0LB?/'1"0L`````(G!P>$%
MB4PD,(G1BVPD,(G"#ZS*&XM,)"@)U8GR`>G!XAZ)U8N4)&@"``")3"1@#ZS[
M`HE,)"B+3"1`"=V!PM;!8LJ)T(EL)$`!R#-L)#B)Z8ML)$B+7"0LBU0D),=$
M)#0`````QT0D)``````QS8M,)"B)[@'&B<C!X`6)1"0PBT0D((ML)#`/K-D;
MB?.+="1`"<V)P0'KP>$>#ZS0`HG-BY0D<`(``(E<)#`)Q8M$)#B+?"0PB6PD
M.(E<)$B!PM;!8LH!T#'NBVPD8(M4)"PQ]8GIBVPD-`'!B?C!X`6)1"0@BW0D
M(`^L[QN+1"0H"?X!\8MT)#B)3"0@B4PD8(G!P>$>#ZS0`HG-BXPD>`(``(M4
M)"0)Q8M$)$")[XGU@<'6P6+*B7PD.`'(,?TS;"1(B>D!P8M$)"#!X`6)QXM$
M)"`/K-`;B40D*(ML)"B+1"0PBU0D-,=$)"P`````QT0D-``````)_0'IB4PD
M2(E,)"B)P0^LT`*+E"2``@``P>$>B<T)Q8GP@<+6P6+*B6PD0`'0,VPD.(M4
M)"PS;"1@B>D!P8M$)"B)RXG&B<>+1"0XP>8%B70D,(ML)#`/K-<;"?V+?"0@
M`>N+;"0DQT0D)`````")7"0PB5PD8(GZB?Z+?"0T#ZSN`L'B'HG5BY0DB`(`
M``GUBW0D0(EL)#B!PM;!8LH!T#'NBVPD2#'UBW0D,(GIB?T!P8GPB??!X`6)
M1"0@BW0D(`^L[QN+1"0H"?X!\8E,)$B)3"0@B<&+5"0LP>$>BWPD.(G-QT0D
M+``````/K-`"BY0DD`(```G%BT0D0(GNB?V!PM;!8LJ)="0X`=`Q]3-L)&"+
M5"0DB>D!P8M$)"")R\'@!8E$)"B+1"0@BVPD*`^LT!N+5"0TQT0D-`````")
M1"1`"VPD0(M$)#`!ZXG!#ZS0`HN4))@"``#!X1Z)7"0HB<V)7"1@"<6)^('"
MUL%BRHEL)$`!T#-L)#B+5"0L,VPD2(GI`<&+1"0HB<:)Q\'F!8ET)#"+;"0P
M#ZS7&PG]BWPD(`'IBVPD)(E,)$B)3"0PB?J)_@^L[@+!XAZ)U8N4)*`"``"+
M1"0X"?6+="1`BWPD-(EL)#C'1"0D`````('"UL%BR@'0,>Z+;"1@BU0D+,=$
M)"P`````,?6+="0PB>F)_0'!B?")]XG+P>`%B40D((M$)"B+="0@#ZSO&XG!
M"?Z+?"0X`?/!X1X/K-`"B<V+E"2H`@``B5PD(`G%BT0D0(E<)&")[HG]@<+6
MP6+*B70D:`'0,?4S;"1(BU0D)(GI`<&+1"0@P>`%B40D*(M$)""+;"0H#ZS0
M&XM4)#2)1"0X"VPD.(M$)#`!Z8E,)$")3"0HB<$/K-`"BY0DL`(``,'A'HG-
M"<6)^('"UL%BRHEL)#@!T#'U,VPD8(M4)"S'1"0T`````(GI`<&+1"0HB<N)
MQHG'BT0D:,'F!8ET)#"+;"0P#ZS7&PG]BWPD(`'KBVPD),=$)"0`````B5PD
M,(E<)$B)^HG^BWPD-`^L[@+!XAZ)U8N4)+@"```)]8MT)#B);"1H@<+6P6+*
M`=`Q[HML)$"+5"0L,?6+="0PB>F)_0'!B?")]\'@!8E$)""+="0@#ZSO&XM$
M)"@)_HM\)&@!\8E,)"")3"1@B<'!X1X/K-`"B<V+E"3``@``"<6+1"0XB>Z)
M_8'"UL%BRHET)#@!T#'U,VPD2(GI`<&+1"0@B<O!X`6)1"0HBT0D((M4)"2+
M;"0HQT0D+``````/K-`;BU0D-,=$)#0`````B40D0(M$)#`+;"1`B<$!Z\'A
M'@^LT`*+E"3(`@``B<V+C"3,`@``"<6)7"1(B5PD*(GXB6PD0('"UL%BRH/1
M`(G+B=$QT@'($=HS;"0X,=LS;"1@B>D!P8M$)"@1TXM4)"R)QHG'BT0D.,'F
M!8ET)#"+;"0P#ZS7&S'2"?V+?"0@`>F+;"0D$=.)3"0PB4PD8(GZB?Z+?"0T
M#ZSN`L'B'HE<)&2)U8N4)-`"```)]8MT)$");"0X@<+6P6+*`=`Q[HML)$@Q
M]8MT)#")Z8G]`<&)\(GWB<O!X`6)1"0@BW0D((M$)"B+5"0L#ZSO&\=$)"0`
M````QT0D+``````)_HG!BWPD.`'SP>$>#ZS0`HN4)-@"``")S8N,)-P"```)
MQ8M$)$")7"0@B5PD2(GNB?V!PM;!8LJ#T0")RXG1,=(!R!':,?4S;"1@,=N)
M="1@B>D!P8M$)"`1TXM4)"3!X`6)1"0HBT0D((ML)"@/K-`;,=*)1"0X"VPD
M.(M$)#`!Z1'3BU0D-(E,)"B)3"1`B<&)7"1$P>$>#ZS0`HN4).`"``")S8N,
M).0"```)Q8GXB6PD.('"UL%BRH/1`(G+B=$QT@'($=HQ]3-L)$@QVXGI`<&+
M1"0H$=.+5"0LB<:)Q\'F!8ET)#"+;"0PB=X/K-<;B<LQTHM$)&`)_8M\)"#'
M1"0T``````'KBVPD),=$)"0`````$=:)7"0PB5PD2(ET)$R)^HG^#ZSN`L'B
M'HM\)$")U8N4).@"```)]8MT)#B);"1@@<+6P6+*`=`Q[HM4)"PQ]XMT)#")
M^8M\)#0!P8GPP>`%B?V)]XE$)""+="0@#ZSO&XML)&`)_HGP`<B)1"0@BT0D
M*(G!#ZS0`L'A'HM4)#`)P8M$)#B)SXM,)#2)TXE\)$#!XQZ)SHE<)"@/I-8>
M#ZS*`L'I`HET)"R)[HE,)#2+C"3P`@``B50D,('!UL%BR@'(,?XS="1(B?$!
MP8M$)"#!X`6)QHM$)""+5"0DBUPD*`^LT!O!ZAN)1"0XBWPD.(E4)#P)]XGX
MBWPD5`'(B<&+1"08`TPD$`-$)"`+7"0PQT<$`````,='#`````#'1Q0`````
MQT<<`````(D/QT<D`````(E'"(G8`P0DB4<0BT0D0`-$)`B)1QB)Z`-$)%B)
M1R"+A"3\`@``93,%%````'4+@<0,`P``6UY?7</H02```)!55U93Z!?7__^!
MP\>-``"#[!R%P`^$G@```(N++`$``(L)A<F)3"0(#X2*````#[8(A,ET!8#Y
M/75&,?:+?"0(BR^%[70OB50D#(E$)`1FD(/L!%;_="0,5>BRT___@\00A<!U
M!X!\-0`]="R#QP2++X7M==N#Q!R)Z%M>7UW#D(G&@\8!#[8.A,ET!8#Y/77Q
M*<;KIXUV`(GZ*U0D"(M$)`R-;#4!P?H"B1"#Q!R)Z%M>7UW#C78`,>WKN8UT
M)@!75HG&4^A/U___@<(&C0``@^P0B[HL`0``C5PD"&6A%````(E$)`PQP(G:
MB?#H#O___X7`=#.+5"0(BP>-!)"+4`2%THD0=.&0C;0F`````(/`!(M0!(72
MB1!U](G:B?#HV_[__X7`=<V+1"0,93,%%````'4'@\006UY?P^C^'@``C;0F
M`````(V\)P````!55XG%5E.)UNC#U?__@<-SC```@^PX9:$4````B40D*#'`
M,<"`.CT/E,`!QE;H/M'__X/$$(D$)(GHC50D&.AM_O__A<`/A`T!``"#[`R)
MQU#H&M'__X/$$#L$)`^#W@```(M$)!B-#(4`````BX,L`0``B40D!`^V10"$
MP`^$I0$``#P]#X2=`0``B>CK!I"`^CUT"H/``0^V$(32=?$IZ(M4)`2#[`R+
M.@'/BTPD#(U$"`)0Z%;0__^#Q!"%P(D'#X1U`0``BU0D!(U-`8L"BU0D&(L4
MD`^V10`\/8@"=".$P'4/ZQV)]HV\)P`````\/700@\$!#[9!_X/"`83`B`)U
M[,8"/3'`C;0F``````^V#`:(3`(!@\`!A,EU\3'`BUPD'&4S'10````/A10!
M``"#Q"Q;7E]=PXVV`````(/&`0^V1O^#QP&$P(A'_W7OZ\R0C70F`(N#+`$`
M`(L0B40D!(LZA?\/A,(````QP.L(C;8`````B?B->`&+#+J%R77TC02%#```
M`(N+<!$``(7)=6N)5"0(@^P,QX-P$0```0```%#H9,___X/$$(7`#X2%````
MC0R]`````(/L!%&+5"00B4PD%%*)1"044.CKS?__BTPD%(M$)!B#Q!")`8M,
M)`R+1"0(QT2X!`````")?"08Z7S^__^0C70F`(/L"%!2Z/;.__^+3"04B40D
M&(/$$(7`B0%T(8T,O0````#KPHUT)@`QP.ER_O__D+@(````,?_I3____[C_
M____Z=O^___HI1P``)"-="8`55>)Q593Z'73__^!PR6*``"![(P```!EH10`
M``")1"1\,<"%[70&@'T``'4CBT0D?&4S!10````/A2<!``"!Q(P```!;7E]=
MPXVT)@````"#[`Q5Z'?0__^)1"00@\00A<!TR8V#H9+__XE$)`2-@Z"2__^)
M1"0(@^P,_W0D#.C,S___@\00A<`/A+$```"-4!.+?"0$N0(```")UO.F=->+
M?"0(N0,```")UO.F=,B)5"0,@^P,5>ACSO__BU0D'(G&B10DB50D'.A1SO__
MC40&`HD$).CES?__B<986HM4)!2-@Z.2__]255!J_VH!5NCJS___@\0<C40D
M(%!6:@/H>L___X/$$(/X_W00BT0D+"4`\```/0!```!T/H/L#%;HZ<S__X/$
M$(/L#%;H3<S__X/$$.D]____D(UT)@"#[`S_="0,Z'3/__^)+"3H;,S__X/$
M$.G1_O__B?#HG?[__^O%Z#8;``"-M@````!75HG'4^@&TO__@<.VB```@^P,
MB[,(`0``_S;H`,___X/$#`4\`0``4%=J`^C_SO__@\00A<!T"%LQP%Y?PV:0
M@^P,_S;HUL[__XN`3`$``(/$$"4`\```/0!```!T'X/L#/\VZ+?.__^+@$P!
M``"#Q!`E`/```#T`H```=;J#[`AJ`E?H!\[__X/$$(7`#Y3`6P^VP%Y?PY"-
MM"8`````55>)QU93Z&71__^!PQ6(``"![#`0``!EH10```")A"0@$```,<")
M5"0,:/\/``"-@ZF2__^-="0D5E#HX,O__X/$$(7`#XZ-````C6C_BY,(`0``
M@'PL'`"+$G13B<6)5"0,@^P$56HO5N@AS?__@\00A<"+5"0,=#Z#[`Q2Z/W-
M__]55E=0Z)3-__^#Q""+A"0<$```93,%%````'5#@<0L$```6UY?7<.-M@``
M``"%[76KC70F`(/L#%+HO\W__X/$#/]T)`Q74.AAR___@\00Z[N-="8`BX,(
M`0``BQ#KUNBI&0``B?:-O"<`````4^AZT/__@<,JAP``@^P4BX,(`0``_S#H
M=,W__XV3G)3__U*-D[B2____LP0!``!24.@ZS/__@\0H6\.0C70F`%93Z#G0
M__^!P^F&``"#[!"+LP@!``#_-N@SS?__B00DZ)O___]8_S;H(\W__UJ-DTV4
M__]9:@!24HV3L(W__U*-D]22__]24.ACS/__@\0D6U[#C;8`````C;PG````
M`%575E/HU\___X'#AX8``('L'"```&6A%````(F$)`P@```QP.C'RO__C9.T
MDO__@^P(4E"-@^F2__]0:`$0``!J`8UT)"96Z/3,__^#Q!QH`!```(V\)!,0
M``!75N@NRO__@\00A<!X1XG&C4`!@^P,4.BIRO__@\00A<")Q703@^P$5E=0
MZ'7)___&1#4``(/$$(N,)`P@``!E,PT4````B>AU#X'$'"```%M>7UW#,>WK
MW^A'&```C;0F`````.D[____C70F`(V\)P````!55U93Z`?/__^!P[>%``"!
M[#P0``"+O"10$```C50D*(NT)%00``!EH10```")A"0L$```,<"-@_62__^)
M?"0,Z*OW__^#[`B)Q6HO5^@^RO__@\00A<!T-XM\)`R-@_Z2__^)^NC6^/__
MB?B+E"0L$```93,5%`````^%H`$``('$/!```%M>7UW#D(UT)@"#[`S_="08
MZ!3*__]:68E$)!R-@PN3__^)1"084%;H[<K__X/$$(7`B<9TG8V#H9+__X`^
M`(E$)!R+@P@!``")1"08#X3H````C;0F`````(7M=!6#[`A65>CBQ___@\00
MA<`/A*0```"#[`Q6Z*[)__^#Q!"`?`;_+W42C70F`(/H`8!\!O\OQ@0&`'3R
MBTPD%(U$"`$]_P\```^/*/___XV##9/__X/L!/]T)!!0C8,(E/__5E!H`!``
M`&H!C70D2%;H&,O__X/$%(M\)"3_-^BZRO__@\0,!3P!``!05FH#Z)G*__^#
MQ!"%P'4?@^P,_S?HF,K__XN`3`$``(/$$"4`\```/0"```!T4X/L"/]T)!AJ
M`.CUR?__@\00A<")Q@^$H?[__X`^``^%'____X7M=!.+?"0<N0(```")[O.F
M=,F-="8`BW0D'+@!````Z3C___^-=@"-O"<`````@^P(:@%6Z)7)__^#Q!"%
MP'6;C8/^DO__B?+H,??__X/L#%;H",?__X/$$.E,_O__Z`L6``"-="8`C;PG
M`````(M4)`0/M@J)T(3)=!N-=@"#P@&`^2\/M@H/1,*$R77P\\.-M@````#S
MPXVV`````%93Z*G,__^!PUF#``"#[!2+="0@A?9T.`^V%H32=#&(5"0/@^P,
M5N@DR/__C40&_X/$$`^V5"0/.<9R"^L^9I"#Z`$YQG0Y@#@O=/3K)V:0C8.A
MDO__@^P,4.AAQO__@\00@\046U[#D(VT)@````"`."]T,(/H`3G&<O0YQG4E
M@/HO=,N-@PV3__^#[`Q0Z"S&__^#Q!#KR8VT)@````"`."]U!X/H`3G&<O0I
M\(U0`H'Z`!```'<G@\`!:``0``!05HVS<`$``%;H,<C__X/$$(GP@\046U[#
MC;8`````,<#I>____XGVC;PG`````%=64^BXR___@<-H@@``@^PP9:$4````
MB40D+#'`BX-XE/__C70D!(E$)`J+@WR4__^)1"0.BX.`E/__B40D$HN#A)3_
M_XE$)!:+@XB4__^)1"0:BX.,E/__B40D'HN#D)3__XE$)"*+@Y24__^)1"0F
M#[>#F)3__V:)1"0JC8,/D___Z-CT__^-@QB3___HS?3__XV#()/__^C"]/__
MC8,ID___Z+?T__^-@S"3___HK/3__XV#0)/__^BA]/__C8/UDO__Z);T__^-
M@TR3___HB_3__XV#5I/__^B`]/__C8-@D___Z'7T__^-@_Z2___H:O3__XV#
M:I/__XGRZ)WS__^%P'0-B<*-@U:3___HW/3__XV#>Y/__XGRZ'_S__^%P'0-
MB<*-@XV3___HOO3__XV#F)/__XGRZ&'S__^%P'0UB<*-@_62___HH/3__XV3
MQ)/__XV#,)/__^B/]/__BT0D+&4S!10```!U48/$,%M>7\.-=@"-@ZB3__^)
M\N@;\___A<!U)XUT)!N-N[F3__^Y"@```/.F=;2-5"0EC8-,D___Z$7T___K
MHXUV`(G"C8-,D___Z#/T___KD>@<$P``C;8`````C;\`````4^CJR?__@<.:
M@```@^P89:$4````B40D##'`BX,X`0``@_C_=!J+3"0,93,-%````'4^@\08
M6\.0C;0F`````(U4)`B-@TR3___H@?+__XG",<"%TG02#[82@/HP#Y7!,<"$
MT@^5P"'(B8,X`0``Z[7HFA(``(UV`(V\)P````!3Z&K)__^!PQJ```"#[`CH
MW,/__X/L#%#H,\/__X/$$(7`=`R+`(/$"%O#D(UT)@`QP.ORC;8`````C;\`
M````55=64^@GR?__@</7?P``@^P<9:$4````B40D##'`C50D"(V#QI/__XM\
M)##HW_'__X7`=&N`.`")QG1D@^P(5U#HFL+__X/$$(7`=6"#[`Q7Z'K$__^)
MQ8DT).APQ/__C40%`HD$).@$Q/__B<6-@PN3__^#Q`Q64(V#")3__U=0:O]J
M`57H!<;__XV#QI/__X/$((GJZ,7R___K$(UV`(V#QI/__XGZZ+/R__^+1"0,
M93,%%````'4(@\0<6UY?7</HB1$``(GVC;PG`````%575E/H5\C__X'#!W\`
M`('L/($``(N$)%"!``"-5"0\C;/6D___QT0D2`````#'1"1L`````(ET)$S'
M1"14`````(E$)!")5"0(9:$4````B80D+($``#'`C8/BD___B40D0(V#H9+_
M_XE$)$2-@XV3__^)1"0$B40D6(V#AI/__XE$)%R-@^>3__^)1"1@C8.CD___
MB40D9(V#[Y/__XE$)&B-@_.3__^)1"10C8/UDO__Z(CP__^%P'0)@#@`#X4K
M`@``Z";^__^%P(G%#X1D`@``@^P,5>@CP___C40``8D$).BWPO__B40D$(/$
M$(!]``!T+(LT)(V[_)/__Y`/MD4`@^P,@\4!4%=J_VH!5H/&`NBGQ/__@\0@
M@'T``'7>C7PD6(M$)`2+;"0(ZPV#QP2+!X7`#X1K`0``B>KH_.___X7`B<9T
MYH`X`'3AZ/ST__^%P'38@^P,5N@/P?__@\00A<")Q@^$.@$``&:0B?"+"(/`
M!(V1__[^_O?1(<J!XH"`@(!TZ8G1P>D0]\*`@```#T31C4@"#T3!B=$`T8L,
M)(/8`RGPBSF#P02-E__^_O[WUR'Z@>*`@("`=.F)UXLL),'O$/?"@(````]$
MUXUY`@]%^8G1`-&#WP.#[`PI[XV\.`0$``!7Z+#!__^)1"00B<&-@P&4__]5
M4(V##9/__XE$)#A0C8,&E/__5HG.4&K_:@%1Z*/#__^#Q"AHP`$``%;H-<+_
M_X/$$(/X_W40Z#C"__^+`(/X$0^%?PD``(NS"`$``(/L#/\VZ!W#__^#Q`P%
M/`$``%#_="0(:@/H&</__X/$$(7`B<4/A"P!``"#[`S_="0,BT0D(/\PC8/D
ME/__4(N#``$``&H!_S#HJ<+__X/$(,=$)`0`````ZVR-="8`,?^-M@````"+
M=+Q`A?9T,(`^`'0KB?"#QP'HB?/__X7`=.6#[`Q6Z)R___^#Q!"%P'35B<;I
MCO[__XVV`````#'VZ8'^__^0@^P,4(E$)!#H,_S__XM$)!")!"3H9[___XE$
M)!2#Q!"+C"0L@0``93,-%````(M$)`0/A80)``"!Q#R!``!;7E]=PY"-="8`
MB?`Q_X7`=!V+5"0(@\<!Z/3M__^%P'0%@#@`=2N+1+Q,A<!UXX/L#(VKVY/_
M_VH-Z#/`__^)1"00@\00Z7W]__^-M"8`````@^P,4.CGOO__@\00A<!TQ8G%
MZ3W]__^)]HV\)P````"#[`S_-NC&P?__BX!,`0``@\00)0#P```]`$````^%
ML?[__X/L#/\VZ*/!__^+@%0!``")1"04Z`2___^#Q!`Y1"0$#X6+_O__@^P,
M_S;H?<'__XN`3`$``(/$$"7_`0``/<`!```/A6C^__^#[`Q7Z(N___^+5"08
MB40D%(V#T9/__^@8[?__@\00A<`/A%T!``"#[`Q0Z#2^__]>7U"+1"0<_S#H
M!O7__XE$)!B#Q!"%P`^$-P$``(/L#(M\)!17Z)J___^#Q!"#^`-V,HE\)`B-
M=`?\C;L/E/__N04```#SIG4;@_@$#X2R!@``BWPD"(!\!_LO#X2C!@``C78`
MZ,OY__^%P'4=@^P(:@#_="04Z&F___^)1"0@@\00A<`/A=H```"-D\23__^-
MLTV4__^-@TR3__^-NS:4___HK>W__^B(OO__5E"-@RB4____="0H_W0D#%!J
M_VH!_W0D(.BZP/__@\0@B70D"(MT)`3K-I"-="8`Z%.___^#.!%U/>A)OO__
M@\4!@^P,_W0D%%50_W0D./]T)!Q7:O]J`5;H>L#__X/$,(/L"&C``0``5N@)
MO___@\00@_C_=+F#[`S_="0,Z/6\__^+?"04C8/UDO__B?KH%.W__XD\).BL
M^?__@\00Z83]__^-="8`BT0D$(L`B40D".FZ_O__D&H":O]J[HM\)!Q7Z+"]
M__^#Q`QJ!HV$)#0!``")1"004%?H:;S__X/$$("\)"P!````=0Z`O"0M`0``
M0P^$,08``&H`:@!J`/]T)!SH;[W__\>$)(`````!(T5GQX0DA`````````#'
MA"2(````B:O-[\>$)(P`````````QX0DD````/[<NIC'A"24`````````,>$
M))@```!V5#(0QX0DG`````````#'A"2@````\.'2P\>$)*0`````````QX0D
MJ`````````#'A"2L`````````,>$)+``````````QX0DM`````````#'A"3X
M`````````(/$$(U$)'")1"0LC80DJ````(E$)"2-="8`@^P$:`"```#_="00
M_W0D'.AKN___@\00A<")Q0^.[@$``(NT))@```"+O"2<````B>B9P>`#B6PD
M&(E4)!R+C"2D`````?"#_P"+E"2@````=P0YQG8&@\(!@]$`BWPD'(MT)!B)
MA"28````BX0DZ````,>$))P`````````#ZS^'<'O'0'6$<^%P(FT)*````")
MO"2D````#X1A`0``ND`````IPCG5#T[5`T0D)(/L!%+_="00B==0Z!&[__^+
MA"3X`````?B)A"3X````@\00@_A`#X4E____BT0D+"G]`WPD".C&P?__C;8`
M````@_T_#X[H````@^U`B>B);"0HB?W!Z`:-<`&)1"08P>8&`?Z+?"0LB?:-
MO"<`````BT4`@\5`B80DJ````(M%Q(F$)*P```"+1<B)A"2P````BT7,B80D
MM````(M%T(F$)+@```"+1=2)A"2\````BT78B80DP````(M%W(F$),0```"+
M1>")A"3(````BT7DB80DS````(M%Z(F$)-````"+1>R)A"34````BT7PB80D
MV````(M%](F$)-P```"+1?B)A"3@````BT7\B80DY````(GXZ.;`__\Y]0^%
M3O___XM$)!B)[XML)"C!X`8IQ6I$55?_="0PZ"*[__^)K"3X````@\00Z0/^
M__^-=@"+?"0(Z>?^__^-M"8`````@^P,_W0D'.C$O/__BY0DK````(N$)*@`
M``"+O"2P````BZPDM````(E$)!B)5"0<#ZS0`XE\)"");"0D@^`_C5`!QH0$
MN````("#Q!"#^C@/CW4"``"X.````#'_*=`#5"0D@_@$#X.O`@``A<!T"Z@"
MQ@(`#X5E`P``BWPD$(ML)!2)^`^LZ!B(A"3@````B?@/K.@0BVPD#(B$).$`
M``")^(M\)`B(I"3B````B(0DXP```(GX#ZSH&(B$).0```")^`^LZ!"(A"3E
M````B?B(I"3F````B(0DYP```(M$)"SHN+___XMT)'"+?"1TB?*)\0^L^AB(
MK"3Q````B(PD\@````^VPHB4).\```")\HMT)'@/K/H0BWPD?(B4)/````")
M\HGQB*PD]0```(B,)/8````/K/H8B)0D\P```(GRB[0D@`````^L^A"+O"2$
M````B)0D]````(GRB?&(K"3Y````B(PD^@````^L^AB(E"3W````B?*+M"2(
M````#ZSZ$(N\)(P```"(E"3X````B?*)\8BL)/T```"(C"3^````#ZSZ&(B4
M)/L```")\HNT))`````/K/H0B[PDE````(B4)/P```")\HGQB*PD`0$``(B,
M)`(!``"-C"0#`0``#ZSZ&(E,)!")S8V,)"L!``"(E"3_````B?*-M"3P````
M#ZSZ$(E,)`B-N_R3__^(E"0``0``Z0T```"-M"8`````#[8&@\8!@^P,4%=J
M_VH!58/%`NC`NO__@\0@.6PD"'7?C8--E/__QH0D*P$```!0C8,9E/___W0D
M%/]T)"C_="0,4&K_:@'_="0@Z(BZ__^#Q"#I'_K__XM$)!"+4`2%T@^$4?G_
M_X/L#%*)5"0@Z*2X__^#Q!"#^`,/ACCY__^+5"00C;L4E/__N04```"-=`+\
M\Z8/150D"(E4)`CI%?G__XM,)"2X0`````'1*=!T#3'2Q@01`(/"`3G"<O6+
M1"0LZ+"]__^+?"0DN0X````QP/.KZ7G]__^#[`A0_W0D#(M$)"#_,(V#J)3_
M_^FL]O__C4H$QP(`````QT0"_`````"#X?PIR@'"@^+\@_H$#X(\_?__@^+\
M,<")/`&#P`0YT'+VZ2C]__^`O"0N`0``00^%P?G__X"\)"\!``!##X6S^?__
M@+PD,`$``$@/A:7Y__^`O"0Q`0``10^%E_G__VH":O]JQHMT)!Q6Z`6W__^#
MQ`QJ*8M\)!!75NC%M?__C8--E/__4(V#&93__U?_="0X_W0D'%!J_VH!_W0D
M,.@QN?__@\0PZ<CX__^)]HV\)P`````Q[6:);`+^Z8_\___HSP0``.L-D)"0
MD)"0D)"0D)"0D%575E/HE[O__X'#1W(``(/L.(N["`$``&6A%````(E$)"@Q
MP/\WZ(6X__]=_S>)QNA[N/__#[96:(A0:8U$)"B)1"0<B<*-@S"3___H+^3_
M_X/$$(7`=`F`.#$/A*\"``#H>N___X/L#/\WZ$"X__^-DT>4__]J"VH!4E#H
M;[;__X/$((7`#X3^````BT`,@[MX$0```8LOBT`8B40D"`^.YP```#'VZSV-
MM"8`````BT(,@^P(C58!4(N#=!$``/\TD(E4)!3HE+3__X/$$(7`BXMX$0``
M=6^+5"0$C4(!B=8YP7YB@^P,5>C!M___:@!6_W0D(%#H1+?__X/$((7`=#V+
M$(LOBT(()0`$(``]``0``'2:B50D!(/L#%7HC;?__VH":@"+5"0<4E#H/K7_
M_XLO@\0@Z7?___^-="8`BXMX$0``BR^-0?\Y\'4]@_D!?CB)Z+X!````BVPD
M".L)C;0F`````(L'@^P,@\8!4.@ZM___6EE54.A1M/__@\00.;-X$0``?]Z+
M+X/L#%7H&[?__XV33)3__VH#:@%24.A*M?__@\0@A<")QG0RBT`,@^P,BRC_
M-^CRMO__C9-.E/__@\0,4E50Z)&T__^+1@R#Q!"+,/9&"D`/A6\!``"#[`S_
M-^C%MO__C9-3E/__:@-J`5)0Z/2T__^#Q""%P(G&=#:+5"0,C8/^DO__Z&SB
M__^%P(G%#X0"`0``BT8,@^P,BS#_-^B#MO__@\0,5590Z"BT__^#Q!"#[`S_
M-^AKMO__C9-5E/__@\0,:@%24.@9M?__B<98_S?H3[;__XV3:I3__X/$#%)6
M4.CNL___6O\WZ#:V__^+5"0<QD!I`(V#]9+__^CSX?__@\00A<")QHF#?!$`
M`'1$@^P(:,`!``!6Z/:T__^-4`&#Q!"#^@%V"8/X$0^%L@```(M$)!QE,P44
M````#X6<````@\0L6UY?7<.)]HV\)P````"#[`S_LW01``#H4O#__X/$$(7`
MB<:)@WP1``!UGXV#.)7__X/L#%#H=+3__XUT)@"`>`$`#X1,_?__Z4+]__^0
MBX-T$0``@^P,BRB+1@R+,/\WZ'FU__^)ZHGPZ/#F__^#Q!#I\_[__Y"-M"8`
M````@^P,_S?H5K7__UE=5E#H?;3__X/$$.EV_O__Z%`!``!0BX-T$0``5O\P
MC8-<E?__4.CZL___C78`C;PG`````%=64XM<)!#H8P```(''M&X``(/L#%/H
M1>O__P^V$(/$$(G&A-)T&8GVC;PG`````(/``8#Z+P^V$`]$\(32=?#HV^W_
M_X7;=!B%P'04@#L`=`^-OP&4__^Y!````/.F=`1;7E_#B=A;7E_I(>3__XL\
M),-FD&:09I!FD&:09I"04^B*M___@<,Z;@``@^P(C8,T`0``A<!T'XL`4/]T
M)!S_="0<_W0D'.A3LO__@\086\.-M@`````QP.O?9I!FD%575E/H1[?__X'#
M]VT``(/L#(ML)""-L_3^___HJ[#__XV#\/[__RG&P?X"A?9T)3'_C;8`````
M@^P$_W0D+/]T)"Q5_Y2[\/[__X/'`8/$$#G^=>.#Q`Q;7E]=PXUV`//#9I!F
MD&:09I!FD&:09I!3Z-JV__^!PXIM``"#[`CH/+'__U.#[`CHP[;__X'#<VT`
M`(/$"%O#`P````$``@`N+@`E<R\E<P`O<')O8R]S96QF+V5X90!$>6YA3&]A
M9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R
M;V,O)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!0
M15),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-0
M05=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!
M3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"
M04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,1%],24)2
M05)97U!!5$@`55-%4@!365-414T`+W1M<`!414U01$E2`%1-4`!54T523D%-
M10`E,#)X`'!A<BT`)7,E<R5S)7,`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S
M`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``P
M`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#,W`"UE`"TM````7U]%3E9?4$%2
M7T-,14%.7U\@("`@("`@("`@("`@("``````<&5R;'AS:2YC````)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F
M92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI
M"@``56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3
M("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE
M('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G
M;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2![
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE
M<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B
M('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD
M:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7
M:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]
M/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP
M<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P
M,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@
M)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD
M*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F
M;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.
M('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA
M;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S
M97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@
M("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G
M+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/
M4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P
M87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A
M;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R
M;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I
M>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@
M/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@
M/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K
M(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D
M(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D
M<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X
M(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^
M/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P
M,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O
M9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A
M9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B
M3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO
M=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F
M:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA
M;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D
M969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M
M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,
M24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U
M;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65]
M(#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN
M86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H
M<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C
M:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U
M;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[
M)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D
M14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![
M"FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I
M;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH
M)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE
M(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE
M+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@
M(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T
M=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@
M9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M
M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D
M24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF
M("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M
M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@
M+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES
M='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP
M,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A21553
M12!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S
M<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;
M,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C
M;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@
M=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*
M:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@
M0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE
M;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,[
M"G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU
M<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D
M9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E
M("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I
M9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q
M(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q
M)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D
M;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z
M("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#([
M"GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI
M('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I
M<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`
M05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI
M=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U
M="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I
M;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P
M,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I
M;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM
M>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M
M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI
M.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B([
M"F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U
M;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U
M="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ
M3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ
M3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD
M+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII
M9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A
M?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I
M"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L
M(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V
M86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H
M)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B
M/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S
M970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<[
M"GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD
M;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM
M>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N
M92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X
M<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@
M0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R
M.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT
M(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R
M96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*
M9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS
M:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>
M+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y
M.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@
M)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D
M;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL
M97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*
M;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X
M=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL
M92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O
M;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB
M=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#
M86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT
M(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z
M.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI
M.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O
M)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N
M86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I
M*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I
M;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D
M8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M
M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W
M('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U
M+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(
M03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G
M(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D
M;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P
M96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D
M9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T
M>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA
M;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI
M.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D
M(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S
M=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I
M;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P
M96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB
M0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP
M.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!
M4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A
M"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@
M:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M
M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@
M;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*
M*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@[
M"FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z
M.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I
M.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M
M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA
M;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI
M.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@
M=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE
M9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/
M(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D
M,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N
M<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=
M('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D
M,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M
M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M
M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D
M;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A
M=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@
M9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I
M<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*
M<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R
M<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E
M($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O
M<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U
M:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N
M9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E
M<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ
M1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S
M.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@
M?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U
M:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4
M:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L
M24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@
M=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD
M<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH
M;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!4
M14U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N
M;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@[
M"FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E
M='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN
M,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.
M86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D
M<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\
M("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O
M7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB
M+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA
M;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@
M-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#([
M"G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS
M92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG
M97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I
M;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@
M*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U
M+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T
M>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O
M9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*
M8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D[
M"GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[
M4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL
M87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY
M("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE
M(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2![
M"FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@
M)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z
M("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E
M("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E
M.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M
M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA
M;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*
M)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E
M>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M
M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O
M<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII
M9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M
M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD
M<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C
M:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.
M5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@
M)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?
M9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R
M;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S
M="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*
M<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM0
M05)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@
M/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_
M(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G
M;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D
M0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)
M04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?
M24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%
M04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L
M971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#
M3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'
M3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT[
M"GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM0
M05)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#
M3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@
M;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A
M;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T
M=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?
M7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@
M>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA
M<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB
M97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD
M;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H
M:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A
M<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B
M)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE
M<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I
M(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D
M0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I
M(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``1L#._``
M```=````'''__PP!``#L=/__,`$``/QT__]X#0``?'C__T0!``!<H/__B`$`
M`!RA___L`0``K*'__R0"``#\H___I`(``&RE__]<`P``#*;__\P#``#\IO__
M:`0``#RG__^8!```G*?__^0$``!<J/__=`4``&RH__^(!0``G*K__X0&``#,
MJO__F`8``+RK___\!@``C*W__S0'```,KO__6`<``$RN__^$!P``'*____`'
M``#<N___O`L``&R___\P#0``V[___\`-``#LO___U`T``"S`__\(#@``C,#_
M_U0.``"<P/__:`X``!0``````````7I2``%\"`$;#`0$B`$``"`````<````
M"'#__]`#````#@A&#@Q*#PMT!'@`/QH[*C(D(A````!`````M'/__Q``````
M````0````%0````P=___WR<```!!#@B%`D$.#(<#1`X0A@1!#A2#!48.H`8#
MR"<*#A1!PPX00<8.#$''#@A!Q0X$00L```!@````F````,R>__^\`````$$.
M"(4"00X,AP-!#A"&!$$.%(,%3@XP`D$.-$$..$0./$$.0$@.,%<*#A1#PPX0
M0<8.#$''#@A!Q0X$0@MN"@X40\,.$$'&#@Q!QPX(0<4.!$0+-````/P````H
MG___@@````!!#@B'`D$.#(8#0PX0@P1.#B`"9@H.$$'##@Q!Q@X(0<<.!$$+
M``!\````-`$``("?__]+`@```$$."(4"00X,AP-##A"&!$$.%(,%4`Y,5PY0
M2`Y`60Y,0PY02`Y``D\.3$T.4$@.0`)X"@X40<,.$$'&#@Q!QPX(0<4.!$<+
M`EP.3$L.4$@.0%(.1$$.2$D.3$4.4%`.0&,.2$$.3$$.4%`.0````+0```"T
M`0``4*'__VH!````00X(A0)!#@R'`T,.$(8$00X4@P51#J`!;0H.%$'##A!!
MQ@X,0<<."$'%#@1("T,.K`%!#K`!3`Z@`5L.K`%$#K`!2`Z@`7`.K`%!#K`!
M9@ZL`4$.J`%+#JP!00ZP`4$.M`%"#K@!0@Z\`4$.P`%(#J0!10ZH`4$.K`%"
M#K`!2`Z@`5@.K`%!#K`!2`Z@`4,.K`%!#K`!2`Z@`4T.K`%$#K`!4`Z@`0!L
M````;`(```BB__^8`````$$."(<"00X,A@-##A"#!$X.'$@.($@.%$8.&$$.
M'$(.($@.$$4*PPX,0\8."$''#@1#"T,.'$(.($X.$$\.'$(.($X.$$\.&$(.
M'$$.($@.$$;##@Q$Q@X(0<<.!```F````-P"```XHO__YP````!!#@B%`D$.
M#(<#0PX0A@1!#A2#!5$.Q"!8#L@@2P[,($$.T"!(#L`@8P[$($$.R"!"#LP@
M00[0($@.P"!+#LP@00[0($8.U"!!#M@@00[<($$.X"!(#L`@5@H.%$'##A!!
MQ@X,0<<."$'%#@1'"TL.S"!!#M`@2`[$($0.R"!!#LP@00[0($@.P"``+```
M`'@#``",HO__.P````!!#@B#`DX.'$@.($P.)$P.*$$.+$$.,$@."$'##@0`
M2````*@#``"<HO__4P````!!#@B&`D$.#(,#3@X<2`X@3@X<0@X@1@X<1PX8
M0@X<00X@00XD1PXH1PXL00XP2`X,0<,."$'&#@0``(P```#T`P``L*+__[D`
M````00X(A0)!#@R'`T$.$(8$00X4@P51#K!`70ZX0$$.O$!!#L!`1P[$0$4.
MR$!"#LQ`10[00$@.M$!%#KA`2`Z\0$$.P$!(#K!`3`Z\0$$.P$!(#K!`20ZT
M0$$.N$!!#KQ`00[`0$T.L$!8"@X40<,.$$'&#@Q!QPX(0<4.!$$+`!````"$
M!```X*+__P4`````````^````)@$``#<HO__)0(```!!#@B%`D$.#(<#00X0
MA@1!#A2#!5$.T"!S#M@@1`[<($$.X"!(#M`@<0H.%$'##A!!Q@X,0<<."$'%
M#@1&"T,.W"!$#N`@1@[<($$.V"!/#MP@00[@($@.T"!Q#M@@00[<($$.X"!(
M#M`@2P[<($$.X"!(#M`@=0[4($0.V"!!#MP@1P[@($$.Y"!%#N@@0@[L($4.
M\"!(#MP@1@[@($@.U"!&#M@@00[<($(.X"!(#M`@1P[<($(.X"!.#M`@3P[8
M($0.W"!"#N`@2`[0(`)%#M@@0@[<($$.X"!(#M`@5`[<($$.X"!(#M`@$```
M`)0%```0I/__*@````````!@````J`4``"RD___G`````$$."(8"00X,@P-.
M#B!6#BQ!#C!,#B!F#BQ!#C!(#B!#"@X,0<,."$'&#@1)"UX.+$$.,$@.(&H.
M)$$.*$$.+$<.,$@.($4*#@Q!PPX(0<8.!$<+-`````P&``"XI/__Q`$```!!
M#@B'`D$.#(8#00X0@P1.#D`#8`$*#A!!PPX,0<8."$''#@1$"P`@````1`8`
M`%"F__]V`````$$."(,"3@X@9PH."$'##@1)"P`H````:`8``*RF__\T````
M`$$."(,"3@X02`X<00X@2`X020H."$'##@1&"V@```"4!@``P*;__\<`````
M00X(A0)!#@R'`T$.$(8$00X4@P5.#C!M#CA!#CQ!#D!(#C!'#CQ!#D!F#C1!
M#CA!#CQ'#D!!#D1"#DA"#DQ!#E!.#C!I"@X40<,.$$'&#@Q!QPX(0<4.!$$+
M`,@#````!P``)*?__[$,````00X(A0)!#@R'`T$.$(8$00X4@P51#M""`@+"
M#MR"`D$.X(("6`[0@@)7#MR"`D0.X(("00[D@@)"#NB"`D(.[(("00[P@@)+
M#M""`G\.W(("00[@@@)(#M""`@)]#MR"`DH.X(("4@[D@@)!#NB"`DL.[(("
M1P[P@@)##O2"`D(.^(("0@[\@@)!#H"#`D@.V(("10[<@@)!#N""`D@.T(("
M7@[<@@)"#N""`D@.U(("1@[8@@)$#MR"`D(.X(("2`[0@@)-#MR"`D0.X(("
M1@[D@@)'#NB"`D@.[(("0@[P@@)(#M""`G0.W(("00[@@@)(#M""`EP.W(("
M00[@@@)<#M""`EX*#A1!PPX00<8.#$''#@A!Q0X$1@MH#MR"`D@.X(("3`[0
M@@)/#MR"`D$.X(("2`[0@@)7#MR"`D(.X(("3@[0@@)3#MR"`D(.X(("5P[0
M@@)-#MR"`D(.X(("3@[0@@)3#MR"`D$.X(("6P[0@@)+#MR"`D$.X(("1@[<
M@@)!#MB"`D$.W(("1@[@@@),#M""`DL.W(("10[@@@)(#M""`@)##MB"`D(.
MW(("1`[@@@),#M""`FL.U(("00[8@@)*#MR"`D0.X(("00[D@@)"#NB"`D(.
M[(("1`[P@@)(#M""`F0.W(("1`[@@@)!#N2"`D$.Z(("1`[L@@)$#O""`D$.
M](("0@[X@@)"#OR"`D$.@(,"2`[0@@)##MB"`D4.W(("00[@@@)(#M""`D@.
MW(("1`[@@@)A#M""`EL.U(("0@[8@@)"#MR"`D4.X(("2`[4@@)"#MB"`DP.
MW(("00[@@@)(#M""`EH.U(("0@[8@@)"#MR"`D0.X(("`JT.T(("6@[4@@)%
M#MB"`D0.W(("1`[@@@)(#M""`@*:#M2"`D$.V(("1`[<@@)##N""`E@.T(("
M`Q$!#M2"`D$.V(("00[<@@)$#N""`D\.T(("6P[<@@)$#N""`@)&#M""`@/D
M`0[<@@)!#N""`D$.Y(("0@[H@@)"#NR"`D$.\(("2P[0@@)5#M2"`DH.V(("
M1`[<@@)$#N""`D$.Y(("0@[H@@)"#NR"`D0.\(("2`[0@@)7#MR"`D$.X(("
M3`[0@@("9@H.V(("00[<@@)$#N""`D8.Y(("2PL"<@[4@@)"#MB"`D(.W(("
M10[@@@)(#M2"`D(.V(("10[<@@)!#N""`DP.Y(("1P[H@@)$#NR"`D0.\(("
M00[T@@)"#OB"`D(._(("1`Z`@P)(#M""`@```'`!``#,"@``&+#__X8#````
M00X(A0)!#@R'`T$.$(8$00X4@P5.#DQ4#E!&#DQ"#E!F#D!5#DQ"#E!-#E1"
M#EA!#EQ!#F!(#D!R#DA$#DQ)#E!,#D!:#DQ!#E!'#E1!#EA$#EQ!#F!(#D!>
M#DQ!#E!'#E1"#EA%#EQ!#F!*#D!V#DQ$#E!&#DQ!#DA!#DQ!#E!(#D!-#DQ!
M#E!-#E1"#EA!#EQ!#F!(#D!,#DQ$#E!.#D1!#DA!#DQ!#E!+#D!/#DQ"#E!-
M#E1"#EA!#EQ!#F!(#D!E#DQ$#E!(#D1!#DA!#DQ!#E!(#D!##DQ"#E!.#D1"
M#DA!#DQ!#E!(#DQ"#E!.#D1!#DA!#DQ!#E!&#DQ"#E!;#D!/#DA%#DQ!#E!+
M#D!B"@X40<,.$$'&#@Q!QPX(0<4.!$H+0PH.3$8.4$@.0%4.3$$.4$D+60Y,
M20Y040Y`4`Y,0@Y01@Y,00Y(00Y,00Y02`Y`2PY$1PY(0@Y,1PY0`$0```!`
M#```-++__V\`````00X(AP)!#@R&`T$.$(,$4@X<00X@2PX0`D$*PPX,0<8.
M"$''#@1!"T/##@Q!Q@X(0<<.!````$0```"(#```?&?__SP"````1`P!`$<0
M!0)U`$8/`W5P!A`'`G5\$`8"=7@0`P)U=`-W`0K!#`$`0<-!QD''0<5##`0$
M00L``!````#0#```$[+__P0`````````,````.0,```0LO__/`````!!#@B#
M`DX.$$T.%$0.&$0.'$0.($@."$'##@1'#A"#`@```$@````8#0``'++__UT`
M````00X(A0)!#@R'`T$.$(8$00X4@P5.#B!I#B1$#BA$#BQ!#C!-#B!'#A1!
MPPX00<8.#$''#@A!Q0X$```0````9`T``#"R__\"`````````!@```!X#0``
M+++__Q0`````00X(@P).#A``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````$!D``,`8```!`````0````$```#+`0``
M`0```!H"```,````G!$```T```!480``&0```,#-```;````!````!H```#$
MS0``'`````0```#U_O]OK`$```4```#L"```!@```(P"```*````V00```L`
M```0````%0`````````#````T,X```(```#@`0``%````!$````7````O`\`
M`!$````T#P``$@```(@````3````"````!X````(````^___;P$```C^__]O
ME`X``/___V\"````\/__;\8-``#Z__]O!0``````````````````````````
M``````````````````````````````#(S0````````````#6$0``YA$``/81
M```&$@``%A(``"82```V$@``1A(``%82``!F$@``=A(``(82``"6$@``IA(`
M`+82``#&$@``UA(``.82``#V$@``!A,``!83```F$P``-A,``$83``!6$P``
M9A,``'83``"&$P``EA,``*83``"V$P``QA,``-83``#F$P``]A,```84```6
M%```)A0``#84``!&%```5A0``&84``!V%```AA0``)84``"F%```MA0``,84
M``#6%```YA0``/84```&%0``%A4``"85```V%0``1A4``%85``!F%0``=A4`
M`(85``````````````````````````````````````````````````"@%0``
M``````````````````````30``#_____<&0``$=#0SH@*%5B=6YT=2`W+C(N
M,"TQ,G5B=6YT=3$I(#<N,BXP`$=#0SH@*%5B=6YT=2`V+C0N,"TX=6)U;G1U
M,2D@-BXT+C`@,C`Q-S$P,3```"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"
M22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD
M>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR
M96PN<&QT`"YI;FET`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H
M7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`
M+F1Y;F%M:6,`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````
M````````````````````````````````"P````$````"````5`$``%0!```3
M```````````````!`````````!,````'`````@```&@!``!H`0``(```````
M````````!``````````A````!P````(```"(`0``B`$``"0`````````````
M``0`````````-````/;__V\"````K`$``*P!``#@````!0`````````$````
M!````#X````+`````@```(P"``",`@``8`8```8````!````!````!````!&
M`````P````(```#L"```[`@``-D$``````````````$`````````3@```/__
M_V\"````Q@T``,8-``#,````!0`````````"`````@```%L```#^__]O`@``
M`)0.``"4#@``H`````8````"````!`````````!J````"0````(````T#P``
M-`\``(@````%``````````0````(````<P````D```!"````O`\``+P/``#@
M`0``!0```!8````$````"````'P````!````!@```)P1``"<$0``(P``````
M````````!`````````!W`````0````8```#`$0``P!$``-`#````````````
M`!`````$````@@````$````&````D!4``)`5```0```````````````(````
M"````(L````!````!@```*`5``"@%0``M$L`````````````$`````````"1
M`````0````8```!480``5&$``!0```````````````0`````````EP````$`
M```"````:&$``&AA```\/P`````````````$`````````)\````!`````@``
M`*2@``"DH```]```````````````!`````````"M`````0````(```"8H0``
MF*$``)0-``````````````0`````````MP````X````#````P,T``,"]```$
M```````````````$````!````,,````/`````P```,3-``#$O0``!```````
M````````!`````0```#/````!@````,```#(S0``R+T```@!```&````````
M``0````(````A@````$````#````T,X``-"^```P`0`````````````$````
M!````-@````!`````P````#0````P```$```````````````!`````````#>
M````"`````,````@T```$,```#00`````````````"``````````XP````$`
M```P`````````!#```!0```````````````!`````0````$````#````````
=``````!@P```[````````````````0``````````
